[PATCH 09/19] setterm: fix shadow declaration

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



term-utils/setterm.c:221:55: warning: declaration of 'opt_term' shadows a global declaration [-Wshadow]
term-utils/setterm.c:181:5: warning: shadowed declaration is here [-Wshadow]

Signed-off-by: Sami Kerola <kerolasa@xxxxxx>
---
 term-utils/setterm.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/term-utils/setterm.c b/term-utils/setterm.c
index 3083ac8..03148f7 100644
--- a/term-utils/setterm.c
+++ b/term-utils/setterm.c
@@ -218,11 +218,11 @@ static void screendump(int vcnum, FILE *F);
  */
 
 static void
-parse_term(int argc, char **argv, int *option, char **opt_term, int *bad_arg) {
+parse_term(int argc, char **argv, int *option, char **opt_trm, int *bad_arg) {
 	/* argc: Number of arguments for this option. */
 	/* argv: Arguments for this option. */
 	/* option: Term flag to set. */
 	/* opt_term: Terminal name to set. */
 	/* bad_arg: Set to true if an error is detected. */
 
 /* Parse a -term specification. */
@@ -231,7 +231,7 @@ parse_term(int argc, char **argv, int *option, char **opt_term, int *bad_arg) {
 		*bad_arg = TRUE;
 	*option = TRUE;
 	if (argc == 1)
-		*opt_term = argv[0];
+		*opt_trm = argv[0];
 }
 
 static void
@@ -218,11 +218,11 @@ static void screendump(int vcnum, FILE *F);
 	/* argv: Arguments for this option. */
 	/* option: Term flag to set. */
-	/* opt_term: Terminal name to set. */
+	/* opt_trm: Terminal name to set. */
 	/* bad_arg: Set to true if an error is detected. */
 
-- 
1.7.11.3

--
To unsubscribe from this list: send the line "unsubscribe util-linux" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[Index of Archives]     [Netdev]     [Ethernet Bridging]     [Linux Wireless]     [Kernel Newbies]     [Security]     [Linux for Hams]     [Netfilter]     [Bugtraq]     [Yosemite News]     [MIPS Linux]     [ARM Linux]     [Linux RAID]     [Linux Admin]     [Samba]

  Powered by Linux